@@ -29,6 +29,8 @@ ansi = {'reset': esc+'0m',
 	'restore_screen': esc+'?47l',
 	'move_up_line': esc+'F',
 	'clear_line': esc+'K',
+	'line_wrap_off': esc+'?7l',
+	'line_wrap_on': esc+'?7h',
 	}
 
 # we define a subclass of string
